package cn.service.system;

import java.util.List;
import java.util.Map;

import cn.pojo.entity.TSysRole;
import cn.pojo.entity.TSysRolePerm;

public interface IRoleService  
{
	List<Map<String, Object>> getRolePermList();
	Map<String,Object> getRolePerms(Map<String, Object> where);
	
	TSysRole getById(Long roleId);
	Long insertRole(TSysRole role);
	int deleteRoleByIds(Long[] roleIds);
	
	Boolean deleteRoleDeptByRoleId(Long roleId);
	Boolean countUserRoleByRoleId(Long roleId);
	Boolean deleteRoleMenuByRoleId(Long roleId);
	Boolean ifExistRoleMenuPerm(Integer roleId,String menuIds);
	Long updateRoleMenu(TSysRole role);
	Long updateRolePerm(TSysRolePerm role);
	int checkRoleUnique(TSysRole role);
	
	
	Long authDataScope(TSysRole role);
}
